(define (list-entry-decorate-default
 	 new-responses filter-enabled filter-ok new-thread favorite hidden)
  (cond (hidden (cons list-entry-fg-hidden list-entry-bg-hidden))
 	(new-thread (cons list-entry-fg-strong list-entry-bg-strong))
 	(filter-ok
	 (cons (if new-responses list-entry-fg-emph list-entry-fg-normal)
	       (if filter-enabled list-entry-bg-normal list-entry-bg-emph)))
 	nil))

(define (list-entry-decorate-default-old
	 new-responses filter-enabled filter-ok new-thread favorite hidden)
  (cons (if hidden
	    list-entry-fg-hidden
	    (if (and new-responses favorite) list-entry-fg-emph
		list-entry-fg-normal))
	(if new-thread list-entry-bg-strong
	    (if (and new-responses filter-ok) list-entry-bg-emph
		list-entry-bg-normal))))

(define list-entry-decorate list-entry-decorate-default)
;(define list-entry-decorate list-entry-decorate-default-old)


(define (calculate-weight-default
	 rank n-res n-got n-read dead new favorite hidden)
  (+ (if hidden 100000 0)
     (if favorite 0 20000)
     (if (> n-got 0) (- n-got n-res) 10000)
     (if new 0 5000)
     (if dead 10000 0)))

(define calculate-weight calculate-weight-default)
